==> opencascade_7.8.1+dfsg1.orig.tar.xz: occt-V7_8_1/src/IGESSelect/IGESSelect_DispPerSingleView.cxx <==
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.


#include <IFGraph_SubPartsIterator.hxx>
#include <IFSelect_PacketList.hxx>
#include <IFSelect_Selection.hxx>
#include <IGESData_IGESModel.hxx>
#include <IGESSelect_DispPerSingleView.hxx>
#include <IGESSelect_ViewSorter.hxx>
#include <Interface_EntityIterator.hxx>
#include <Interface_Graph.hxx>
#include <Interface_Macros.hxx>
#include <Standard_Type.hxx>
#include <TCollection_AsciiString.hxx>

IMPLEMENT_STANDARD_RTTIEXT(IGESSelect_DispPerSingleView,IFSelect_Dispatch)

IGESSelect_DispPerSingleView::IGESSelect_DispPerSingleView ()
      {  thesorter = new IGESSelect_ViewSorter;  }

    TCollection_AsciiString  IGESSelect_DispPerSingleView::Label () const
{
  return TCollection_AsciiString("One File per single View or Drawing Frame");
}


    void  IGESSelect_DispPerSingleView::Packets
  (const Interface_Graph& G, IFGraph_SubPartsIterator& packs) const
{
  if (FinalSelection().IsNull()) return;
  Interface_EntityIterator list = FinalSelection()->UniqueResult(G);
  thesorter->SetModel (GetCasted(IGESData_IGESModel,G.Model()));
  thesorter->Clear();
  thesorter->AddList (list.Content());
  thesorter->SortSingleViews(Standard_True);
  Handle(IFSelect_PacketList) sets = thesorter->Sets(Standard_True);

  packs.SetLoad();
  Standard_Integer nb = sets->NbPackets();
  for (Standard_Integer i = 1; i <= nb; i ++) {
    packs.AddPart();
    packs.GetFromIter (sets->Entities(i));
  }
}


    Standard_Boolean  IGESSelect_DispPerSingleView::CanHaveRemainder () const
      {  return Standard_True;  }

    Interface_EntityIterator  IGESSelect_DispPerSingleView::Remainder
  (const Interface_Graph& G) const
{
  if (thesorter->NbEntities() == 0) {
    Interface_EntityIterator list;
    if (FinalSelection().IsNull()) return list;
    list = FinalSelection()->UniqueResult(G);
    thesorter->Clear();
    thesorter->Add (list.Content());
    thesorter->SortSingleViews(Standard_True);
  }
  return thesorter->Sets(Standard_True)->Duplicated (0,Standard_False);
}

==> opencascade_7.9.1+dfsg.orig.tar.xz: occt-V7_9_1/src/IGESSelect/IGESSelect_DispPerSingleView.cxx <==
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <IFGraph_SubPartsIterator.hxx>
#include <IFSelect_PacketList.hxx>
#include <IFSelect_Selection.hxx>
#include <IGESData_IGESModel.hxx>
#include <IGESSelect_DispPerSingleView.hxx>
#include <IGESSelect_ViewSorter.hxx>
#include <Interface_EntityIterator.hxx>
#include <Interface_Graph.hxx>
#include <Interface_Macros.hxx>
#include <Standard_Type.hxx>
#include <TCollection_AsciiString.hxx>

IMPLEMENT_STANDARD_RTTIEXT(IGESSelect_DispPerSingleView, IFSelect_Dispatch)

IGESSelect_DispPerSingleView::IGESSelect_DispPerSingleView()
{
  thesorter = new IGESSelect_ViewSorter;
}

TCollection_AsciiString IGESSelect_DispPerSingleView::Label() const
{
  return TCollection_AsciiString("One File per single View or Drawing Frame");
}

void IGESSelect_DispPerSingleView::Packets(const Interface_Graph&    G,
                                           IFGraph_SubPartsIterator& packs) const
{
  if (FinalSelection().IsNull())
    return;
  Interface_EntityIterator list = FinalSelection()->UniqueResult(G);
  thesorter->SetModel(GetCasted(IGESData_IGESModel, G.Model()));
  thesorter->Clear();
  thesorter->AddList(list.Content());
  thesorter->SortSingleViews(Standard_True);
  Handle(IFSelect_PacketList) sets = thesorter->Sets(Standard_True);

  packs.SetLoad();
  Standard_Integer nb = sets->NbPackets();
  for (Standard_Integer i = 1; i <= nb; i++)
  {
    packs.AddPart();
    packs.GetFromIter(sets->Entities(i));
  }
}

Standard_Boolean IGESSelect_DispPerSingleView::CanHaveRemainder() const
{
  return Standard_True;
}

Interface_EntityIterator IGESSelect_DispPerSingleView::Remainder(const Interface_Graph& G) const
{
  if (thesorter->NbEntities() == 0)
  {
    Interface_EntityIterator list;
    if (FinalSelection().IsNull())
      return list;
    list = FinalSelection()->UniqueResult(G);
    thesorter->Clear();
    thesorter->Add(list.Content());
    thesorter->SortSingleViews(Standard_True);
  }
  return thesorter->Sets(Standard_True)->Duplicated(0, Standard_False);
}
